vininfo documentation
=====================
https://github.com/idlesign/vininfo



Description
-----------

*Extracts useful information from Vehicle Identification Number (VIN)*

Here will be an introductory description.



Requirements
------------

1. Python 2.7+



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart


